import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class TranslateResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class GlossariesResource(googleapiclient.discovery.Resource):
                @typing.type_check_only
                class GlossaryEntriesResource(googleapiclient.discovery.Resource):
                    def create(
                        self,
                        *,
                        parent: str,
                        body: GlossaryEntry = ...,
                        **kwargs: typing.Any
                    ) -> GlossaryEntryHttpRequest: ...
                    def delete(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> EmptyHttpRequest: ...
                    def get(
                        self, *, name: str, **kwargs: typing.Any
                    ) -> GlossaryEntryHttpRequest: ...
                    def list(
                        self,
                        *,
                        parent: str,
                        pageSize: int = ...,
                        pageToken: str = ...,
                        **kwargs: typing.Any
                    ) -> ListGlossaryEntriesResponseHttpRequest: ...
                    def list_next(
                        self,
                        previous_request: ListGlossaryEntriesResponseHttpRequest,
                        previous_response: ListGlossaryEntriesResponse,
                    ) -> ListGlossaryEntriesResponseHttpRequest | None: ...
                    def patch(
                        self,
                        *,
                        name: str,
                        body: GlossaryEntry = ...,
                        **kwargs: typing.Any
                    ) -> GlossaryEntryHttpRequest: ...

                def create(
                    self, *, parent: str, body: Glossary = ..., **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> GlossaryHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListGlossariesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListGlossariesResponseHttpRequest,
                    previous_response: ListGlossariesResponse,
                ) -> ListGlossariesResponseHttpRequest | None: ...
                def patch(
                    self,
                    *,
                    name: str,
                    body: Glossary = ...,
                    updateMask: str = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def glossaryEntries(self) -> GlossaryEntriesResource: ...

            @typing.type_check_only
            class OperationsResource(googleapiclient.discovery.Resource):
                def cancel(
                    self,
                    *,
                    name: str,
                    body: CancelOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> EmptyHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> OperationHttpRequest: ...
                def list(
                    self,
                    *,
                    name: str,
                    filter: str = ...,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    **kwargs: typing.Any
                ) -> ListOperationsResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListOperationsResponseHttpRequest,
                    previous_response: ListOperationsResponse,
                ) -> ListOperationsResponseHttpRequest | None: ...
                def wait(
                    self,
                    *,
                    name: str,
                    body: WaitOperationRequest = ...,
                    **kwargs: typing.Any
                ) -> OperationHttpRequest: ...

            def batchTranslateDocument(
                self,
                *,
                parent: str,
                body: BatchTranslateDocumentRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def batchTranslateText(
                self,
                *,
                parent: str,
                body: BatchTranslateTextRequest = ...,
                **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def detectLanguage(
                self,
                *,
                parent: str,
                body: DetectLanguageRequest = ...,
                **kwargs: typing.Any
            ) -> DetectLanguageResponseHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> LocationHttpRequest: ...
            def getSupportedLanguages(
                self,
                *,
                parent: str,
                displayLanguageCode: str = ...,
                model: str = ...,
                **kwargs: typing.Any
            ) -> SupportedLanguagesHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListLocationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListLocationsResponseHttpRequest,
                previous_response: ListLocationsResponse,
            ) -> ListLocationsResponseHttpRequest | None: ...
            def translateDocument(
                self,
                *,
                parent: str,
                body: TranslateDocumentRequest = ...,
                **kwargs: typing.Any
            ) -> TranslateDocumentResponseHttpRequest: ...
            def translateText(
                self,
                *,
                parent: str,
                body: TranslateTextRequest = ...,
                **kwargs: typing.Any
            ) -> TranslateTextResponseHttpRequest: ...
            def glossaries(self) -> GlossariesResource: ...
            def operations(self) -> OperationsResource: ...

        def detectLanguage(
            self,
            *,
            parent: str,
            body: DetectLanguageRequest = ...,
            **kwargs: typing.Any
        ) -> DetectLanguageResponseHttpRequest: ...
        def getSupportedLanguages(
            self,
            *,
            parent: str,
            displayLanguageCode: str = ...,
            model: str = ...,
            **kwargs: typing.Any
        ) -> SupportedLanguagesHttpRequest: ...
        def translateText(
            self, *, parent: str, body: TranslateTextRequest = ..., **kwargs: typing.Any
        ) -> TranslateTextResponseHttpRequest: ...
        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DetectLanguageResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DetectLanguageResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class GlossaryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Glossary: ...

@typing.type_check_only
class GlossaryEntryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GlossaryEntry: ...

@typing.type_check_only
class ListGlossariesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGlossariesResponse: ...

@typing.type_check_only
class ListGlossaryEntriesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGlossaryEntriesResponse: ...

@typing.type_check_only
class ListLocationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListLocationsResponse: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class LocationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Location: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...

@typing.type_check_only
class SupportedLanguagesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SupportedLanguages: ...

@typing.type_check_only
class TranslateDocumentResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TranslateDocumentResponse: ...

@typing.type_check_only
class TranslateTextResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> TranslateTextResponse: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class GenomicsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class PipelinesResource(googleapiclient.discovery.Resource):
        def run(
            self, *, body: RunPipelineRequest = ..., **kwargs: typing.Any
        ) -> OperationHttpRequest: ...

    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class OperationsResource(googleapiclient.discovery.Resource):
            def cancel(
                self,
                *,
                name: str,
                body: CancelOperationRequest = ...,
                **kwargs: typing.Any
            ) -> EmptyHttpRequest: ...
            def get(
                self, *, name: str, **kwargs: typing.Any
            ) -> OperationHttpRequest: ...
            def list(
                self,
                *,
                name: str,
                filter: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListOperationsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListOperationsResponseHttpRequest,
                previous_response: ListOperationsResponse,
            ) -> ListOperationsResponseHttpRequest | None: ...

        @typing.type_check_only
        class WorkersResource(googleapiclient.discovery.Resource):
            def checkIn(
                self, *, id: str, body: CheckInRequest = ..., **kwargs: typing.Any
            ) -> CheckInResponseHttpRequest: ...

        def operations(self) -> OperationsResource: ...
        def workers(self) -> WorkersResource: ...

    @typing.type_check_only
    class WorkersResource(googleapiclient.discovery.Resource):
        def checkIn(
            self, *, id: str, body: CheckInRequest = ..., **kwargs: typing.Any
        ) -> CheckInResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def pipelines(self) -> PipelinesResource: ...
    def projects(self) -> ProjectsResource: ...
    def workers(self) -> WorkersResource: ...

@typing.type_check_only
class CheckInResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CheckInResponse: ...

@typing.type_check_only
class EmptyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Empty: ...

@typing.type_check_only
class ListOperationsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListOperationsResponse: ...

@typing.type_check_only
class OperationHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Operation: ...



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class YouTubeAnalyticsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class GroupItemsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            id: str = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> EmptyResponseHttpRequest: ...
        def insert(
            self,
            *,
            body: GroupItem = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> GroupItemHttpRequest: ...
        def list(
            self,
            *,
            groupId: str = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> ListGroupItemsResponseHttpRequest: ...

    @typing.type_check_only
    class GroupsResource(googleapiclient.discovery.Resource):
        def delete(
            self,
            *,
            id: str = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> EmptyResponseHttpRequest: ...
        def insert(
            self,
            *,
            body: Group = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> GroupHttpRequest: ...
        def list(
            self,
            *,
            id: str = ...,
            mine: bool = ...,
            onBehalfOfContentOwner: str = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListGroupsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListGroupsResponseHttpRequest,
            previous_response: ListGroupsResponse,
        ) -> ListGroupsResponseHttpRequest | None: ...
        def update(
            self,
            *,
            body: Group = ...,
            onBehalfOfContentOwner: str = ...,
            **kwargs: typing.Any
        ) -> GroupHttpRequest: ...

    @typing.type_check_only
    class ReportsResource(googleapiclient.discovery.Resource):
        def query(
            self,
            *,
            currency: str = ...,
            dimensions: str = ...,
            endDate: str = ...,
            filters: str = ...,
            ids: str = ...,
            includeHistoricalChannelData: bool = ...,
            maxResults: int = ...,
            metrics: str = ...,
            sort: str = ...,
            startDate: str = ...,
            startIndex: int = ...,
            **kwargs: typing.Any
        ) -> QueryResponseHttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def groupItems(self) -> GroupItemsResource: ...
    def groups(self) -> GroupsResource: ...
    def reports(self) -> ReportsResource: ...

@typing.type_check_only
class EmptyResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> EmptyResponse: ...

@typing.type_check_only
class GroupHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Group: ...

@typing.type_check_only
class GroupItemHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> GroupItem: ...

@typing.type_check_only
class ListGroupItemsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGroupItemsResponse: ...

@typing.type_check_only
class ListGroupsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListGroupsResponse: ...

@typing.type_check_only
class QueryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> QueryResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ComputeEngine(typing_extensions.TypedDict, total=False):
    diskNames: _list[str]
    instanceName: str
    machineType: str
    zone: str

@typing.type_check_only
class ContainerKilledEvent(typing_extensions.TypedDict, total=False):
    actionId: int

@typing.type_check_only
class ContainerStartedEvent(typing_extensions.TypedDict, total=False):
    actionId: int
    ipAddress: str
    portMappings: dict[str, typing.Any]

@typing.type_check_only
class ContainerStoppedEvent(typing_extensions.TypedDict, total=False):
    actionId: int
    exitStatus: int
    stderr: str

@typing.type_check_only
class ControllerConfig(typing_extensions.TypedDict, total=False):
    cmd: str
    disks: dict[str, typing.Any]
    gcsLogPath: str
    gcsSinks: dict[str, typing.Any]
    gcsSources: dict[str, typing.Any]
    image: str
    machineType: str
    vars: dict[str, typing.Any]

@typing.type_check_only
class DelayedEvent(typing_extensions.TypedDict, total=False):
    cause: str
    metrics: _list[str]

@typing.type_check_only
class Disk(typing_extensions.TypedDict, total=False):
    autoDelete: bool
    mountPoint: str
    name: str
    readOnly: bool
    sizeGb: int
    source: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED", "PERSISTENT_HDD", "PERSISTENT_SSD", "LOCAL_SSD"
    ]

@typing.type_check_only
class DockerExecutor(typing_extensions.TypedDict, total=False):
    cmd: str
    imageName: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Event(typing_extensions.TypedDict, total=False):
    description: str
    details: dict[str, typing.Any]
    timestamp: str

@typing.type_check_only
class FailedEvent(typing_extensions.TypedDict, total=False):
    cause: str
    code: typing_extensions.Literal[
        "OK",
        "CANCELLED",
        "UNKNOWN",
        "INVALID_ARGUMENT",
        "DEADLINE_EXCEEDED",
        "NOT_FOUND",
        "ALREADY_EXISTS",
        "PERMISSION_DENIED",
        "UNAUTHENTICATED",
        "RESOURCE_EXHAUSTED",
        "FAILED_PRECONDITION",
        "ABORTED",
        "OUT_OF_RANGE",
        "UNIMPLEMENTED",
        "INTERNAL",
        "UNAVAILABLE",
        "DATA_LOSS",
    ]

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListPipelinesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    pipelines: _list[Pipeline]

@typing.type_check_only
class LocalCopy(typing_extensions.TypedDict, total=False):
    disk: str
    path: str

@typing.type_check_only
class LoggingOptions(typing_extensions.TypedDict, total=False):
    gcsPath: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationEvent(typing_extensions.TypedDict, total=False):
    description: str
    endTime: str
    startTime: str

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    clientId: str
    createTime: str
    endTime: str
    events: _list[OperationEvent]
    labels: dict[str, typing.Any]
    projectId: str
    request: dict[str, typing.Any]
    runtimeMetadata: dict[str, typing.Any]
    startTime: str

@typing.type_check_only
class Pipeline(typing_extensions.TypedDict, total=False):
    description: str
    docker: DockerExecutor
    inputParameters: _list[PipelineParameter]
    name: str
    outputParameters: _list[PipelineParameter]
    pipelineId: str
    projectId: str
    resources: PipelineResources

@typing.type_check_only
class PipelineParameter(typing_extensions.TypedDict, total=False):
    defaultValue: str
    description: str
    localCopy: LocalCopy
    name: str

@typing.type_check_only
class PipelineResources(typing_extensions.TypedDict, total=False):
    acceleratorCount: str
    acceleratorType: str
    bootDiskSizeGb: int
    disks: _list[Disk]
    minimumCpuCores: int
    minimumRamGb: float
    noAddress: bool
    preemptible: bool
    zones: _list[str]

@typing.type_check_only
class PullStartedEvent(typing_extensions.TypedDict, total=False):
    imageUri: str

@typing.type_check_only
class PullStoppedEvent(typing_extensions.TypedDict, total=False):
    imageUri: str

@typing.type_check_only
class RepeatedString(typing_extensions.TypedDict, total=False):
    values: _list[str]

@typing.type_check_only
class RunPipelineArgs(typing_extensions.TypedDict, total=False):
    clientId: str
    inputs: dict[str, typing.Any]
    keepVmAliveOnFailureDuration: str
    labels: dict[str, typing.Any]
    logging: LoggingOptions
    outputs: dict[str, typing.Any]
    projectId: str
    resources: PipelineResources
    serviceAccount: ServiceAccount

@typing.type_check_only
class RunPipelineRequest(typing_extensions.TypedDict, total=False):
    ephemeralPipeline: Pipeline
    pipelineArgs: RunPipelineArgs
    pipelineId: str

@typing.type_check_only
class RunPipelineResponse(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class RuntimeMetadata(typing_extensions.TypedDict, total=False):
    computeEngine: ComputeEngine

@typing.type_check_only
class ServiceAccount(typing_extensions.TypedDict, total=False):
    email: str
    scopes: _list[str]

@typing.type_check_only
class SetOperationStatusRequest(typing_extensions.TypedDict, total=False):
    errorCode: typing_extensions.Literal[
        "OK",
        "CANCELLED",
        "UNKNOWN",
        "INVALID_ARGUMENT",
        "DEADLINE_EXCEEDED",
        "NOT_FOUND",
        "ALREADY_EXISTS",
        "PERMISSION_DENIED",
        "UNAUTHENTICATED",
        "RESOURCE_EXHAUSTED",
        "FAILED_PRECONDITION",
        "ABORTED",
        "OUT_OF_RANGE",
        "UNIMPLEMENTED",
        "INTERNAL",
        "UNAVAILABLE",
        "DATA_LOSS",
    ]
    errorMessage: str
    operationId: str
    timestampEvents: _list[TimestampEvent]
    validationToken: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TimestampEvent(typing_extensions.TypedDict, total=False):
    description: str
    timestamp: str

@typing.type_check_only
class UnexpectedExitStatusEvent(typing_extensions.TypedDict, total=False):
    actionId: int
    exitStatus: int

@typing.type_check_only
class WorkerAssignedEvent(typing_extensions.TypedDict, total=False):
    instance: str
    machineType: str
    zone: str

@typing.type_check_only
class WorkerReleasedEvent(typing_extensions.TypedDict, total=False):
    instance: str
    zone: str



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class ShoppingContentResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class AccountsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class CredentialsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                accountId: str,
                body: AccountCredentials = ...,
                **kwargs: typing.Any
            ) -> AccountCredentialsHttpRequest: ...

        @typing.type_check_only
        class LabelsResource(googleapiclient.discovery.Resource):
            def create(
                self, *, accountId: str, body: AccountLabel = ..., **kwargs: typing.Any
            ) -> AccountLabelHttpRequest: ...
            def delete(
                self, *, accountId: str, labelId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def list(
                self,
                *,
                accountId: str,
                pageSize: int = ...,
                pageToken: str = ...,
                **kwargs: typing.Any
            ) -> ListAccountLabelsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListAccountLabelsResponseHttpRequest,
                previous_response: ListAccountLabelsResponse,
            ) -> ListAccountLabelsResponseHttpRequest | None: ...
            def patch(
                self,
                *,
                accountId: str,
                labelId: str,
                body: AccountLabel = ...,
                **kwargs: typing.Any
            ) -> AccountLabelHttpRequest: ...

        @typing.type_check_only
        class ReturncarrierResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                accountId: str,
                body: AccountReturnCarrier = ...,
                **kwargs: typing.Any
            ) -> AccountReturnCarrierHttpRequest: ...
            def delete(
                self, *, accountId: str, carrierAccountId: str, **kwargs: typing.Any
            ) -> googleapiclient.http.HttpRequest: ...
            def list(
                self, *, accountId: str, **kwargs: typing.Any
            ) -> ListAccountReturnCarrierResponseHttpRequest: ...
            def patch(
                self,
                *,
                accountId: str,
                carrierAccountId: str,
                body: AccountReturnCarrier = ...,
                **kwargs: typing.Any
            ) -> AccountReturnCarrierHttpRequest: ...

        def authinfo(
            self, **kwargs: typing.Any
        ) -> AccountsAuthInfoResponseHttpRequest: ...
        def claimwebsite(
            self,
            *,
            merchantId: str,
            accountId: str,
            overwrite: bool = ...,
            **kwargs: typing.Any
        ) -> AccountsClaimWebsiteResponseHttpRequest: ...
        def custombatch(
            self, *, body: AccountsCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> AccountsCustomBatchResponseHttpRequest: ...
        def delete(
            self,
            *,
            merchantId: str,
            accountId: str,
            force: bool = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            merchantId: str,
            accountId: str,
            view: typing_extensions.Literal["MERCHANT", "CSS"] = ...,
            **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def insert(
            self, *, merchantId: str, body: Account = ..., **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def link(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: AccountsLinkRequest = ...,
            **kwargs: typing.Any
        ) -> AccountsLinkResponseHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            label: str = ...,
            maxResults: int = ...,
            name: str = ...,
            pageToken: str = ...,
            view: typing_extensions.Literal["MERCHANT", "CSS"] = ...,
            **kwargs: typing.Any
        ) -> AccountsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: AccountsListResponseHttpRequest,
            previous_response: AccountsListResponse,
        ) -> AccountsListResponseHttpRequest | None: ...
        def listlinks(
            self,
            *,
            merchantId: str,
            accountId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> AccountsListLinksResponseHttpRequest: ...
        def listlinks_next(
            self,
            previous_request: AccountsListLinksResponseHttpRequest,
            previous_response: AccountsListLinksResponse,
        ) -> AccountsListLinksResponseHttpRequest | None: ...
        def requestphoneverification(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: RequestPhoneVerificationRequest = ...,
            **kwargs: typing.Any
        ) -> RequestPhoneVerificationResponseHttpRequest: ...
        def update(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: Account = ...,
            **kwargs: typing.Any
        ) -> AccountHttpRequest: ...
        def updatelabels(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: AccountsUpdateLabelsRequest = ...,
            **kwargs: typing.Any
        ) -> AccountsUpdateLabelsResponseHttpRequest: ...
        def verifyphonenumber(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: VerifyPhoneNumberRequest = ...,
            **kwargs: typing.Any
        ) -> VerifyPhoneNumberResponseHttpRequest: ...
        def credentials(self) -> CredentialsResource: ...
        def labels(self) -> LabelsResource: ...
        def returncarrier(self) -> ReturncarrierResource: ...

    @typing.type_check_only
    class AccountstatusesResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: AccountstatusesCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> AccountstatusesCustomBatchResponseHttpRequest: ...
        def get(
            self,
            *,
            merchantId: str,
            accountId: str,
            destinations: str | _list[str] = ...,
            **kwargs: typing.Any
        ) -> AccountStatusHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            destinations: str | _list[str] = ...,
            maxResults: int = ...,
            name: str = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> AccountstatusesListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: AccountstatusesListResponseHttpRequest,
            previous_response: AccountstatusesListResponse,
        ) -> AccountstatusesListResponseHttpRequest | None: ...

    @typing.type_check_only
    class AccounttaxResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: AccounttaxCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> AccounttaxCustomBatchResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, accountId: str, **kwargs: typing.Any
        ) -> AccountTaxHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> AccounttaxListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: AccounttaxListResponseHttpRequest,
            previous_response: AccounttaxListResponse,
        ) -> AccounttaxListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: AccountTax = ...,
            **kwargs: typing.Any
        ) -> AccountTaxHttpRequest: ...

    @typing.type_check_only
    class BuyongoogleprogramsResource(googleapiclient.discovery.Resource):
        def activate(
            self,
            *,
            merchantId: str,
            regionCode: str,
            body: ActivateBuyOnGoogleProgramRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, regionCode: str, **kwargs: typing.Any
        ) -> BuyOnGoogleProgramStatusHttpRequest: ...
        def onboard(
            self,
            *,
            merchantId: str,
            regionCode: str,
            body: OnboardBuyOnGoogleProgramRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def patch(
            self,
            *,
            merchantId: str,
            regionCode: str,
            body: BuyOnGoogleProgramStatus = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> BuyOnGoogleProgramStatusHttpRequest: ...
        def pause(
            self,
            *,
            merchantId: str,
            regionCode: str,
            body: PauseBuyOnGoogleProgramRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def requestreview(
            self,
            *,
            merchantId: str,
            regionCode: str,
            body: RequestReviewBuyOnGoogleProgramRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class CollectionsResource(googleapiclient.discovery.Resource):
        def create(
            self, *, merchantId: str, body: Collection = ..., **kwargs: typing.Any
        ) -> CollectionHttpRequest: ...
        def delete(
            self, *, merchantId: str, collectionId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, collectionId: str, **kwargs: typing.Any
        ) -> CollectionHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListCollectionsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCollectionsResponseHttpRequest,
            previous_response: ListCollectionsResponse,
        ) -> ListCollectionsResponseHttpRequest | None: ...

    @typing.type_check_only
    class CollectionstatusesResource(googleapiclient.discovery.Resource):
        def get(
            self, *, merchantId: str, collectionId: str, **kwargs: typing.Any
        ) -> CollectionStatusHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListCollectionStatusesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCollectionStatusesResponseHttpRequest,
            previous_response: ListCollectionStatusesResponse,
        ) -> ListCollectionStatusesResponseHttpRequest | None: ...

    @typing.type_check_only
    class CssesResource(googleapiclient.discovery.Resource):
        def get(
            self, *, cssGroupId: str, cssDomainId: str, **kwargs: typing.Any
        ) -> CssHttpRequest: ...
        def list(
            self,
            *,
            cssGroupId: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListCssesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListCssesResponseHttpRequest,
            previous_response: ListCssesResponse,
        ) -> ListCssesResponseHttpRequest | None: ...
        def updatelabels(
            self,
            *,
            cssGroupId: str,
            cssDomainId: str,
            body: LabelIds = ...,
            **kwargs: typing.Any
        ) -> CssHttpRequest: ...

    @typing.type_check_only
    class DatafeedsResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: DatafeedsCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> DatafeedsCustomBatchResponseHttpRequest: ...
        def delete(
            self, *, merchantId: str, datafeedId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def fetchnow(
            self, *, merchantId: str, datafeedId: str, **kwargs: typing.Any
        ) -> DatafeedsFetchNowResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, datafeedId: str, **kwargs: typing.Any
        ) -> DatafeedHttpRequest: ...
        def insert(
            self, *, merchantId: str, body: Datafeed = ..., **kwargs: typing.Any
        ) -> DatafeedHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> DatafeedsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: DatafeedsListResponseHttpRequest,
            previous_response: DatafeedsListResponse,
        ) -> DatafeedsListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            merchantId: str,
            datafeedId: str,
            body: Datafeed = ...,
            **kwargs: typing.Any
        ) -> DatafeedHttpRequest: ...

    @typing.type_check_only
    class DatafeedstatusesResource(googleapiclient.discovery.Resource):
        def custombatch(
            self,
            *,
            body: DatafeedstatusesCustomBatchRequest = ...,
            **kwargs: typing.Any
        ) -> DatafeedstatusesCustomBatchResponseHttpRequest: ...
        def get(
            self,
            *,
            merchantId: str,
            datafeedId: str,
            country: str = ...,
            language: str = ...,
            **kwargs: typing.Any
        ) -> DatafeedStatusHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> DatafeedstatusesListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: DatafeedstatusesListResponseHttpRequest,
            previous_response: DatafeedstatusesListResponse,
        ) -> DatafeedstatusesListResponseHttpRequest | None: ...

    @typing.type_check_only
    class FreelistingsprogramResource(googleapiclient.discovery.Resource):
        def get(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> FreeListingsProgramStatusHttpRequest: ...
        def requestreview(
            self,
            *,
            merchantId: str,
            body: RequestReviewFreeListingsRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    @typing.type_check_only
    class LiasettingsResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: LiasettingsCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> LiasettingsCustomBatchResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, accountId: str, **kwargs: typing.Any
        ) -> LiaSettingsHttpRequest: ...
        def getaccessiblegmbaccounts(
            self, *, merchantId: str, accountId: str, **kwargs: typing.Any
        ) -> LiasettingsGetAccessibleGmbAccountsResponseHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> LiasettingsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: LiasettingsListResponseHttpRequest,
            previous_response: LiasettingsListResponse,
        ) -> LiasettingsListResponseHttpRequest | None: ...
        def listposdataproviders(
            self, **kwargs: typing.Any
        ) -> LiasettingsListPosDataProvidersResponseHttpRequest: ...
        def requestgmbaccess(
            self,
            *,
            merchantId: str,
            accountId: str,
            gmbEmail: str,
            **kwargs: typing.Any
        ) -> LiasettingsRequestGmbAccessResponseHttpRequest: ...
        def requestinventoryverification(
            self, *, merchantId: str, accountId: str, country: str, **kwargs: typing.Any
        ) -> LiasettingsRequestInventoryVerificationResponseHttpRequest: ...
        def setinventoryverificationcontact(
            self,
            *,
            merchantId: str,
            accountId: str,
            country: str,
            language: str,
            contactName: str,
            contactEmail: str,
            **kwargs: typing.Any
        ) -> LiasettingsSetInventoryVerificationContactResponseHttpRequest: ...
        def setposdataprovider(
            self,
            *,
            merchantId: str,
            accountId: str,
            country: str,
            posDataProviderId: str = ...,
            posExternalAccountId: str = ...,
            **kwargs: typing.Any
        ) -> LiasettingsSetPosDataProviderResponseHttpRequest: ...
        def update(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: LiaSettings = ...,
            **kwargs: typing.Any
        ) -> LiaSettingsHttpRequest: ...

    @typing.type_check_only
    class LocalinventoryResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: LocalinventoryCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> LocalinventoryCustomBatchResponseHttpRequest: ...
        def insert(
            self,
            *,
            merchantId: str,
            productId: str,
            body: LocalInventory = ...,
            **kwargs: typing.Any
        ) -> LocalInventoryHttpRequest: ...

    @typing.type_check_only
    class OrderinvoicesResource(googleapiclient.discovery.Resource):
        def createchargeinvoice(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrderinvoicesCreateChargeInvoiceRequest = ...,
            **kwargs: typing.Any
        ) -> OrderinvoicesCreateChargeInvoiceResponseHttpRequest: ...
        def createrefundinvoice(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrderinvoicesCreateRefundInvoiceRequest = ...,
            **kwargs: typing.Any
        ) -> OrderinvoicesCreateRefundInvoiceResponseHttpRequest: ...

    @typing.type_check_only
    class OrderreportsResource(googleapiclient.discovery.Resource):
        def listdisbursements(
            self,
            *,
            merchantId: str,
            disbursementEndDate: str = ...,
            disbursementStartDate: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> OrderreportsListDisbursementsResponseHttpRequest: ...
        def listdisbursements_next(
            self,
            previous_request: OrderreportsListDisbursementsResponseHttpRequest,
            previous_response: OrderreportsListDisbursementsResponse,
        ) -> OrderreportsListDisbursementsResponseHttpRequest | None: ...
        def listtransactions(
            self,
            *,
            merchantId: str,
            disbursementId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            transactionEndDate: str = ...,
            transactionStartDate: str = ...,
            **kwargs: typing.Any
        ) -> OrderreportsListTransactionsResponseHttpRequest: ...
        def listtransactions_next(
            self,
            previous_request: OrderreportsListTransactionsResponseHttpRequest,
            previous_response: OrderreportsListTransactionsResponse,
        ) -> OrderreportsListTransactionsResponseHttpRequest | None: ...

    @typing.type_check_only
    class OrderreturnsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LabelsResource(googleapiclient.discovery.Resource):
            def create(
                self,
                *,
                merchantId: str,
                returnId: str,
                body: ReturnShippingLabel = ...,
                **kwargs: typing.Any
            ) -> ReturnShippingLabelHttpRequest: ...

        def acknowledge(
            self,
            *,
            merchantId: str,
            returnId: str,
            body: OrderreturnsAcknowledgeRequest = ...,
            **kwargs: typing.Any
        ) -> OrderreturnsAcknowledgeResponseHttpRequest: ...
        def createorderreturn(
            self,
            *,
            merchantId: str,
            body: OrderreturnsCreateOrderReturnRequest = ...,
            **kwargs: typing.Any
        ) -> OrderreturnsCreateOrderReturnResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, returnId: str, **kwargs: typing.Any
        ) -> MerchantOrderReturnHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            acknowledged: bool = ...,
            createdEndDate: str = ...,
            createdStartDate: str = ...,
            googleOrderIds: str | _list[str] = ...,
            maxResults: int = ...,
            orderBy: typing_extensions.Literal[
                "RETURN_CREATION_TIME_DESC", "RETURN_CREATION_TIME_ASC"
            ] = ...,
            pageToken: str = ...,
            shipmentStates: typing_extensions.Literal[
                "NEW", "SHIPPED", "COMPLETED", "UNDELIVERABLE", "PENDING"
            ]
            | _list[
                typing_extensions.Literal[
                    "NEW", "SHIPPED", "COMPLETED", "UNDELIVERABLE", "PENDING"
                ]
            ] = ...,
            shipmentStatus: typing_extensions.Literal["NEW", "IN_PROGRESS", "PROCESSED"]
            | _list[typing_extensions.Literal["NEW", "IN_PROGRESS", "PROCESSED"]] = ...,
            shipmentTrackingNumbers: str | _list[str] = ...,
            shipmentTypes: typing_extensions.Literal[
                "BY_MAIL", "RETURNLESS", "CONTACT_CUSTOMER_SUPPORT"
            ]
            | _list[
                typing_extensions.Literal[
                    "BY_MAIL", "RETURNLESS", "CONTACT_CUSTOMER_SUPPORT"
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> OrderreturnsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: OrderreturnsListResponseHttpRequest,
            previous_response: OrderreturnsListResponse,
        ) -> OrderreturnsListResponseHttpRequest | None: ...
        def process(
            self,
            *,
            merchantId: str,
            returnId: str,
            body: OrderreturnsProcessRequest = ...,
            **kwargs: typing.Any
        ) -> OrderreturnsProcessResponseHttpRequest: ...
        def labels(self) -> LabelsResource: ...

    @typing.type_check_only
    class OrdersResource(googleapiclient.discovery.Resource):
        def acknowledge(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersAcknowledgeRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersAcknowledgeResponseHttpRequest: ...
        def advancetestorder(
            self, *, merchantId: str, orderId: str, **kwargs: typing.Any
        ) -> OrdersAdvanceTestOrderResponseHttpRequest: ...
        def cancel(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersCancelRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersCancelResponseHttpRequest: ...
        def cancellineitem(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersCancelLineItemRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersCancelLineItemResponseHttpRequest: ...
        def canceltestorderbycustomer(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersCancelTestOrderByCustomerRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersCancelTestOrderByCustomerResponseHttpRequest: ...
        def captureOrder(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: CaptureOrderRequest = ...,
            **kwargs: typing.Any
        ) -> CaptureOrderResponseHttpRequest: ...
        def createtestorder(
            self,
            *,
            merchantId: str,
            body: OrdersCreateTestOrderRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersCreateTestOrderResponseHttpRequest: ...
        def createtestreturn(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersCreateTestReturnRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersCreateTestReturnResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, orderId: str, **kwargs: typing.Any
        ) -> OrderHttpRequest: ...
        def getbymerchantorderid(
            self, *, merchantId: str, merchantOrderId: str, **kwargs: typing.Any
        ) -> OrdersGetByMerchantOrderIdResponseHttpRequest: ...
        def gettestordertemplate(
            self,
            *,
            merchantId: str,
            templateName: typing_extensions.Literal[
                "TEMPLATE1",
                "TEMPLATE2",
                "TEMPLATE1A",
                "TEMPLATE1B",
                "TEMPLATE3",
                "TEMPLATE4",
            ],
            country: str = ...,
            **kwargs: typing.Any
        ) -> OrdersGetTestOrderTemplateResponseHttpRequest: ...
        def instorerefundlineitem(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersInStoreRefundLineItemRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersInStoreRefundLineItemResponseHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            acknowledged: bool = ...,
            maxResults: int = ...,
            orderBy: str = ...,
            pageToken: str = ...,
            placedDateEnd: str = ...,
            placedDateStart: str = ...,
            statuses: typing_extensions.Literal[
                "ACTIVE",
                "COMPLETED",
                "CANCELED",
                "IN_PROGRESS",
                "PENDING_SHIPMENT",
                "PARTIALLY_SHIPPED",
                "SHIPPED",
                "PARTIALLY_DELIVERED",
                "DELIVERED",
                "PARTIALLY_RETURNED",
                "RETURNED",
            ]
            | _list[
                typing_extensions.Literal[
                    "ACTIVE",
                    "COMPLETED",
                    "CANCELED",
                    "IN_PROGRESS",
                    "PENDING_SHIPMENT",
                    "PARTIALLY_SHIPPED",
                    "SHIPPED",
                    "PARTIALLY_DELIVERED",
                    "DELIVERED",
                    "PARTIALLY_RETURNED",
                    "RETURNED",
                ]
            ] = ...,
            **kwargs: typing.Any
        ) -> OrdersListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: OrdersListResponseHttpRequest,
            previous_response: OrdersListResponse,
        ) -> OrdersListResponseHttpRequest | None: ...
        def refunditem(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersRefundItemRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersRefundItemResponseHttpRequest: ...
        def refundorder(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersRefundOrderRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersRefundOrderResponseHttpRequest: ...
        def rejectreturnlineitem(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersRejectReturnLineItemRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersRejectReturnLineItemResponseHttpRequest: ...
        def returnrefundlineitem(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersReturnRefundLineItemRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersReturnRefundLineItemResponseHttpRequest: ...
        def setlineitemmetadata(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersSetLineItemMetadataRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersSetLineItemMetadataResponseHttpRequest: ...
        def shiplineitems(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersShipLineItemsRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersShipLineItemsResponseHttpRequest: ...
        def updatelineitemshippingdetails(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersUpdateLineItemShippingDetailsRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersUpdateLineItemShippingDetailsResponseHttpRequest: ...
        def updatemerchantorderid(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersUpdateMerchantOrderIdRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersUpdateMerchantOrderIdResponseHttpRequest: ...
        def updateshipment(
            self,
            *,
            merchantId: str,
            orderId: str,
            body: OrdersUpdateShipmentRequest = ...,
            **kwargs: typing.Any
        ) -> OrdersUpdateShipmentResponseHttpRequest: ...

    @typing.type_check_only
    class OrdertrackingsignalsResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            merchantId: str,
            body: OrderTrackingSignal = ...,
            **kwargs: typing.Any
        ) -> OrderTrackingSignalHttpRequest: ...

    @typing.type_check_only
    class PosResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: PosCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> PosCustomBatchResponseHttpRequest: ...
        def delete(
            self,
            *,
            merchantId: str,
            targetMerchantId: str,
            storeCode: str,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self,
            *,
            merchantId: str,
            targetMerchantId: str,
            storeCode: str,
            **kwargs: typing.Any
        ) -> PosStoreHttpRequest: ...
        def insert(
            self,
            *,
            merchantId: str,
            targetMerchantId: str,
            body: PosStore = ...,
            **kwargs: typing.Any
        ) -> PosStoreHttpRequest: ...
        def inventory(
            self,
            *,
            merchantId: str,
            targetMerchantId: str,
            body: PosInventoryRequest = ...,
            **kwargs: typing.Any
        ) -> PosInventoryResponseHttpRequest: ...
        def list(
            self, *, merchantId: str, targetMerchantId: str, **kwargs: typing.Any
        ) -> PosListResponseHttpRequest: ...
        def sale(
            self,
            *,
            merchantId: str,
            targetMerchantId: str,
            body: PosSaleRequest = ...,
            **kwargs: typing.Any
        ) -> PosSaleResponseHttpRequest: ...

    @typing.type_check_only
    class ProductdeliverytimeResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            merchantId: str,
            body: ProductDeliveryTime = ...,
            **kwargs: typing.Any
        ) -> ProductDeliveryTimeHttpRequest: ...
        def delete(
            self, *, merchantId: str, productId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, productId: str, **kwargs: typing.Any
        ) -> ProductDeliveryTimeHttpRequest: ...

    @typing.type_check_only
    class ProductsResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: ProductsCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> ProductsCustomBatchResponseHttpRequest: ...
        def delete(
            self,
            *,
            merchantId: str,
            productId: str,
            feedId: str = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, productId: str, **kwargs: typing.Any
        ) -> ProductHttpRequest: ...
        def insert(
            self,
            *,
            merchantId: str,
            body: Product = ...,
            feedId: str = ...,
            **kwargs: typing.Any
        ) -> ProductHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ProductsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ProductsListResponseHttpRequest,
            previous_response: ProductsListResponse,
        ) -> ProductsListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            merchantId: str,
            productId: str,
            body: Product = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> ProductHttpRequest: ...

    @typing.type_check_only
    class ProductstatusesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class RepricingreportsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                merchantId: str,
                productId: str,
                endDate: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                ruleId: str = ...,
                startDate: str = ...,
                **kwargs: typing.Any
            ) -> ListRepricingProductReportsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListRepricingProductReportsResponseHttpRequest,
                previous_response: ListRepricingProductReportsResponse,
            ) -> ListRepricingProductReportsResponseHttpRequest | None: ...

        def custombatch(
            self, *, body: ProductstatusesCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> ProductstatusesCustomBatchResponseHttpRequest: ...
        def get(
            self,
            *,
            merchantId: str,
            productId: str,
            destinations: str | _list[str] = ...,
            **kwargs: typing.Any
        ) -> ProductStatusHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            destinations: str | _list[str] = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ProductstatusesListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ProductstatusesListResponseHttpRequest,
            previous_response: ProductstatusesListResponse,
        ) -> ProductstatusesListResponseHttpRequest | None: ...
        def repricingreports(self) -> RepricingreportsResource: ...

    @typing.type_check_only
    class PromotionsResource(googleapiclient.discovery.Resource):
        def create(
            self, *, merchantId: str, body: Promotion = ..., **kwargs: typing.Any
        ) -> PromotionHttpRequest: ...
        def get(
            self, *, merchantId: str, id: str, **kwargs: typing.Any
        ) -> PromotionHttpRequest: ...

    @typing.type_check_only
    class PubsubnotificationsettingsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> PubsubNotificationSettingsHttpRequest: ...
        def update(
            self,
            *,
            merchantId: str,
            body: PubsubNotificationSettings = ...,
            **kwargs: typing.Any
        ) -> PubsubNotificationSettingsHttpRequest: ...

    @typing.type_check_only
    class RegionalinventoryResource(googleapiclient.discovery.Resource):
        def custombatch(
            self,
            *,
            body: RegionalinventoryCustomBatchRequest = ...,
            **kwargs: typing.Any
        ) -> RegionalinventoryCustomBatchResponseHttpRequest: ...
        def insert(
            self,
            *,
            merchantId: str,
            productId: str,
            body: RegionalInventory = ...,
            **kwargs: typing.Any
        ) -> RegionalInventoryHttpRequest: ...

    @typing.type_check_only
    class RegionsResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            merchantId: str,
            body: Region = ...,
            regionId: str = ...,
            **kwargs: typing.Any
        ) -> RegionHttpRequest: ...
        def delete(
            self, *, merchantId: str, regionId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, regionId: str, **kwargs: typing.Any
        ) -> RegionHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListRegionsResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListRegionsResponseHttpRequest,
            previous_response: ListRegionsResponse,
        ) -> ListRegionsResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            merchantId: str,
            regionId: str,
            body: Region = ...,
            updateMask: str = ...,
            **kwargs: typing.Any
        ) -> RegionHttpRequest: ...

    @typing.type_check_only
    class ReportsResource(googleapiclient.discovery.Resource):
        def search(
            self, *, merchantId: str, body: SearchRequest = ..., **kwargs: typing.Any
        ) -> SearchResponseHttpRequest: ...
        def search_next(
            self,
            previous_request: SearchResponseHttpRequest,
            previous_response: SearchResponse,
        ) -> SearchResponseHttpRequest | None: ...

    @typing.type_check_only
    class RepricingrulesResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class RepricingreportsResource(googleapiclient.discovery.Resource):
            def list(
                self,
                *,
                merchantId: str,
                ruleId: str,
                endDate: str = ...,
                pageSize: int = ...,
                pageToken: str = ...,
                startDate: str = ...,
                **kwargs: typing.Any
            ) -> ListRepricingRuleReportsResponseHttpRequest: ...
            def list_next(
                self,
                previous_request: ListRepricingRuleReportsResponseHttpRequest,
                previous_response: ListRepricingRuleReportsResponse,
            ) -> ListRepricingRuleReportsResponseHttpRequest | None: ...

        def create(
            self,
            *,
            merchantId: str,
            body: RepricingRule = ...,
            ruleId: str = ...,
            **kwargs: typing.Any
        ) -> RepricingRuleHttpRequest: ...
        def delete(
            self, *, merchantId: str, ruleId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, ruleId: str, **kwargs: typing.Any
        ) -> RepricingRuleHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            countryCode: str = ...,
            languageCode: str = ...,
            pageSize: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ListRepricingRulesResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ListRepricingRulesResponseHttpRequest,
            previous_response: ListRepricingRulesResponse,
        ) -> ListRepricingRulesResponseHttpRequest | None: ...
        def patch(
            self,
            *,
            merchantId: str,
            ruleId: str,
            body: RepricingRule = ...,
            **kwargs: typing.Any
        ) -> RepricingRuleHttpRequest: ...
        def repricingreports(self) -> RepricingreportsResource: ...

    @typing.type_check_only
    class ReturnaddressResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: ReturnaddressCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> ReturnaddressCustomBatchResponseHttpRequest: ...
        def delete(
            self, *, merchantId: str, returnAddressId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, returnAddressId: str, **kwargs: typing.Any
        ) -> ReturnAddressHttpRequest: ...
        def insert(
            self, *, merchantId: str, body: ReturnAddress = ..., **kwargs: typing.Any
        ) -> ReturnAddressHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            country: str = ...,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ReturnaddressListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ReturnaddressListResponseHttpRequest,
            previous_response: ReturnaddressListResponse,
        ) -> ReturnaddressListResponseHttpRequest | None: ...

    @typing.type_check_only
    class ReturnpolicyResource(googleapiclient.discovery.Resource):
        def custombatch(
            self, *, body: ReturnpolicyCustomBatchRequest = ..., **kwargs: typing.Any
        ) -> ReturnpolicyCustomBatchResponseHttpRequest: ...
        def delete(
            self, *, merchantId: str, returnPolicyId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, returnPolicyId: str, **kwargs: typing.Any
        ) -> ReturnPolicyHttpRequest: ...
        def insert(
            self, *, merchantId: str, body: ReturnPolicy = ..., **kwargs: typing.Any
        ) -> ReturnPolicyHttpRequest: ...
        def list(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ReturnpolicyListResponseHttpRequest: ...

    @typing.type_check_only
    class ReturnpolicyonlineResource(googleapiclient.discovery.Resource):
        def create(
            self,
            *,
            merchantId: str,
            body: ReturnPolicyOnline = ...,
            **kwargs: typing.Any
        ) -> ReturnPolicyOnlineHttpRequest: ...
        def delete(
            self, *, merchantId: str, returnPolicyId: str, **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...
        def get(
            self, *, merchantId: str, returnPolicyId: str, **kwargs: typing.Any
        ) -> ReturnPolicyOnlineHttpRequest: ...
        def list(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ListReturnPolicyOnlineResponseHttpRequest: ...
        def patch(
            self,
            *,
            merchantId: str,
            returnPolicyId: str,
            body: ReturnPolicyOnline = ...,
            **kwargs: typing.Any
        ) -> ReturnPolicyOnlineHttpRequest: ...

    @typing.type_check_only
    class SettlementreportsResource(googleapiclient.discovery.Resource):
        def get(
            self, *, merchantId: str, settlementId: str, **kwargs: typing.Any
        ) -> SettlementReportHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            transferEndDate: str = ...,
            transferStartDate: str = ...,
            **kwargs: typing.Any
        ) -> SettlementreportsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: SettlementreportsListResponseHttpRequest,
            previous_response: SettlementreportsListResponse,
        ) -> SettlementreportsListResponseHttpRequest | None: ...

    @typing.type_check_only
    class SettlementtransactionsResource(googleapiclient.discovery.Resource):
        def list(
            self,
            *,
            merchantId: str,
            settlementId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            transactionIds: str | _list[str] = ...,
            **kwargs: typing.Any
        ) -> SettlementtransactionsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: SettlementtransactionsListResponseHttpRequest,
            previous_response: SettlementtransactionsListResponse,
        ) -> SettlementtransactionsListResponseHttpRequest | None: ...

    @typing.type_check_only
    class ShippingsettingsResource(googleapiclient.discovery.Resource):
        def custombatch(
            self,
            *,
            body: ShippingsettingsCustomBatchRequest = ...,
            **kwargs: typing.Any
        ) -> ShippingsettingsCustomBatchResponseHttpRequest: ...
        def get(
            self, *, merchantId: str, accountId: str, **kwargs: typing.Any
        ) -> ShippingSettingsHttpRequest: ...
        def getsupportedcarriers(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ShippingsettingsGetSupportedCarriersResponseHttpRequest: ...
        def getsupportedholidays(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ShippingsettingsGetSupportedHolidaysResponseHttpRequest: ...
        def getsupportedpickupservices(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ShippingsettingsGetSupportedPickupServicesResponseHttpRequest: ...
        def list(
            self,
            *,
            merchantId: str,
            maxResults: int = ...,
            pageToken: str = ...,
            **kwargs: typing.Any
        ) -> ShippingsettingsListResponseHttpRequest: ...
        def list_next(
            self,
            previous_request: ShippingsettingsListResponseHttpRequest,
            previous_response: ShippingsettingsListResponse,
        ) -> ShippingsettingsListResponseHttpRequest | None: ...
        def update(
            self,
            *,
            merchantId: str,
            accountId: str,
            body: ShippingSettings = ...,
            **kwargs: typing.Any
        ) -> ShippingSettingsHttpRequest: ...

    @typing.type_check_only
    class ShoppingadsprogramResource(googleapiclient.discovery.Resource):
        def get(
            self, *, merchantId: str, **kwargs: typing.Any
        ) -> ShoppingAdsProgramStatusHttpRequest: ...
        def requestreview(
            self,
            *,
            merchantId: str,
            body: RequestReviewShoppingAdsRequest = ...,
            **kwargs: typing.Any
        ) -> googleapiclient.http.HttpRequest: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def accounts(self) -> AccountsResource: ...
    def accountstatuses(self) -> AccountstatusesResource: ...
    def accounttax(self) -> AccounttaxResource: ...
    def buyongoogleprograms(self) -> BuyongoogleprogramsResource: ...
    def collections(self) -> CollectionsResource: ...
    def collectionstatuses(self) -> CollectionstatusesResource: ...
    def csses(self) -> CssesResource: ...
    def datafeeds(self) -> DatafeedsResource: ...
    def datafeedstatuses(self) -> DatafeedstatusesResource: ...
    def freelistingsprogram(self) -> FreelistingsprogramResource: ...
    def liasettings(self) -> LiasettingsResource: ...
    def localinventory(self) -> LocalinventoryResource: ...
    def orderinvoices(self) -> OrderinvoicesResource: ...
    def orderreports(self) -> OrderreportsResource: ...
    def orderreturns(self) -> OrderreturnsResource: ...
    def orders(self) -> OrdersResource: ...
    def ordertrackingsignals(self) -> OrdertrackingsignalsResource: ...
    def pos(self) -> PosResource: ...
    def productdeliverytime(self) -> ProductdeliverytimeResource: ...
    def products(self) -> ProductsResource: ...
    def productstatuses(self) -> ProductstatusesResource: ...
    def promotions(self) -> PromotionsResource: ...
    def pubsubnotificationsettings(self) -> PubsubnotificationsettingsResource: ...
    def regionalinventory(self) -> RegionalinventoryResource: ...
    def regions(self) -> RegionsResource: ...
    def reports(self) -> ReportsResource: ...
    def repricingrules(self) -> RepricingrulesResource: ...
    def returnaddress(self) -> ReturnaddressResource: ...
    def returnpolicy(self) -> ReturnpolicyResource: ...
    def returnpolicyonline(self) -> ReturnpolicyonlineResource: ...
    def settlementreports(self) -> SettlementreportsResource: ...
    def settlementtransactions(self) -> SettlementtransactionsResource: ...
    def shippingsettings(self) -> ShippingsettingsResource: ...
    def shoppingadsprogram(self) -> ShoppingadsprogramResource: ...

@typing.type_check_only
class AccountHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Account: ...

@typing.type_check_only
class AccountCredentialsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountCredentials: ...

@typing.type_check_only
class AccountLabelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountLabel: ...

@typing.type_check_only
class AccountReturnCarrierHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountReturnCarrier: ...

@typing.type_check_only
class AccountStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountStatus: ...

@typing.type_check_only
class AccountTaxHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountTax: ...

@typing.type_check_only
class AccountsAuthInfoResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsAuthInfoResponse: ...

@typing.type_check_only
class AccountsClaimWebsiteResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsClaimWebsiteResponse: ...

@typing.type_check_only
class AccountsCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsCustomBatchResponse: ...

@typing.type_check_only
class AccountsLinkResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsLinkResponse: ...

@typing.type_check_only
class AccountsListLinksResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsListLinksResponse: ...

@typing.type_check_only
class AccountsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsListResponse: ...

@typing.type_check_only
class AccountsUpdateLabelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountsUpdateLabelsResponse: ...

@typing.type_check_only
class AccountstatusesCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountstatusesCustomBatchResponse: ...

@typing.type_check_only
class AccountstatusesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccountstatusesListResponse: ...

@typing.type_check_only
class AccounttaxCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccounttaxCustomBatchResponse: ...

@typing.type_check_only
class AccounttaxListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AccounttaxListResponse: ...

@typing.type_check_only
class BuyOnGoogleProgramStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BuyOnGoogleProgramStatus: ...

@typing.type_check_only
class CaptureOrderResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CaptureOrderResponse: ...

@typing.type_check_only
class CollectionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Collection: ...

@typing.type_check_only
class CollectionStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> CollectionStatus: ...

@typing.type_check_only
class CssHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Css: ...

@typing.type_check_only
class DatafeedHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Datafeed: ...

@typing.type_check_only
class DatafeedStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedStatus: ...

@typing.type_check_only
class DatafeedsCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedsCustomBatchResponse: ...

@typing.type_check_only
class DatafeedsFetchNowResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedsFetchNowResponse: ...

@typing.type_check_only
class DatafeedsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedsListResponse: ...

@typing.type_check_only
class DatafeedstatusesCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedstatusesCustomBatchResponse: ...

@typing.type_check_only
class DatafeedstatusesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatafeedstatusesListResponse: ...

@typing.type_check_only
class FreeListingsProgramStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> FreeListingsProgramStatus: ...

@typing.type_check_only
class LiaSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiaSettings: ...

@typing.type_check_only
class LiasettingsCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsCustomBatchResponse: ...

@typing.type_check_only
class LiasettingsGetAccessibleGmbAccountsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsGetAccessibleGmbAccountsResponse: ...

@typing.type_check_only
class LiasettingsListPosDataProvidersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsListPosDataProvidersResponse: ...

@typing.type_check_only
class LiasettingsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsListResponse: ...

@typing.type_check_only
class LiasettingsRequestGmbAccessResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsRequestGmbAccessResponse: ...

@typing.type_check_only
class LiasettingsRequestInventoryVerificationResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsRequestInventoryVerificationResponse: ...

@typing.type_check_only
class LiasettingsSetInventoryVerificationContactResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsSetInventoryVerificationContactResponse: ...

@typing.type_check_only
class LiasettingsSetPosDataProviderResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LiasettingsSetPosDataProviderResponse: ...

@typing.type_check_only
class ListAccountLabelsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountLabelsResponse: ...

@typing.type_check_only
class ListAccountReturnCarrierResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListAccountReturnCarrierResponse: ...

@typing.type_check_only
class ListCollectionStatusesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCollectionStatusesResponse: ...

@typing.type_check_only
class ListCollectionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCollectionsResponse: ...

@typing.type_check_only
class ListCssesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListCssesResponse: ...

@typing.type_check_only
class ListRegionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRegionsResponse: ...

@typing.type_check_only
class ListRepricingProductReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRepricingProductReportsResponse: ...

@typing.type_check_only
class ListRepricingRuleReportsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRepricingRuleReportsResponse: ...

@typing.type_check_only
class ListRepricingRulesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListRepricingRulesResponse: ...

@typing.type_check_only
class ListReturnPolicyOnlineResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListReturnPolicyOnlineResponse: ...

@typing.type_check_only
class LocalInventoryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LocalInventory: ...

@typing.type_check_only
class LocalinventoryCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> LocalinventoryCustomBatchResponse: ...

@typing.type_check_only
class MerchantOrderReturnHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> MerchantOrderReturn: ...

@typing.type_check_only
class OrderHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Order: ...

@typing.type_check_only
class OrderTrackingSignalHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderTrackingSignal: ...

@typing.type_check_only
class OrderinvoicesCreateChargeInvoiceResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderinvoicesCreateChargeInvoiceResponse: ...

@typing.type_check_only
class OrderinvoicesCreateRefundInvoiceResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderinvoicesCreateRefundInvoiceResponse: ...

@typing.type_check_only
class OrderreportsListDisbursementsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreportsListDisbursementsResponse: ...

@typing.type_check_only
class OrderreportsListTransactionsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreportsListTransactionsResponse: ...

@typing.type_check_only
class OrderreturnsAcknowledgeResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreturnsAcknowledgeResponse: ...

@typing.type_check_only
class OrderreturnsCreateOrderReturnResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreturnsCreateOrderReturnResponse: ...

@typing.type_check_only
class OrderreturnsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreturnsListResponse: ...

@typing.type_check_only
class OrderreturnsProcessResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrderreturnsProcessResponse: ...

@typing.type_check_only
class OrdersAcknowledgeResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersAcknowledgeResponse: ...

@typing.type_check_only
class OrdersAdvanceTestOrderResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersAdvanceTestOrderResponse: ...

@typing.type_check_only
class OrdersCancelLineItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersCancelLineItemResponse: ...

@typing.type_check_only
class OrdersCancelResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersCancelResponse: ...

@typing.type_check_only
class OrdersCancelTestOrderByCustomerResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersCancelTestOrderByCustomerResponse: ...

@typing.type_check_only
class OrdersCreateTestOrderResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersCreateTestOrderResponse: ...

@typing.type_check_only
class OrdersCreateTestReturnResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersCreateTestReturnResponse: ...

@typing.type_check_only
class OrdersGetByMerchantOrderIdResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersGetByMerchantOrderIdResponse: ...

@typing.type_check_only
class OrdersGetTestOrderTemplateResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersGetTestOrderTemplateResponse: ...

@typing.type_check_only
class OrdersInStoreRefundLineItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersInStoreRefundLineItemResponse: ...

@typing.type_check_only
class OrdersListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersListResponse: ...

@typing.type_check_only
class OrdersRefundItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersRefundItemResponse: ...

@typing.type_check_only
class OrdersRefundOrderResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersRefundOrderResponse: ...

@typing.type_check_only
class OrdersRejectReturnLineItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersRejectReturnLineItemResponse: ...

@typing.type_check_only
class OrdersReturnRefundLineItemResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersReturnRefundLineItemResponse: ...

@typing.type_check_only
class OrdersSetLineItemMetadataResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersSetLineItemMetadataResponse: ...

@typing.type_check_only
class OrdersShipLineItemsResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersShipLineItemsResponse: ...

@typing.type_check_only
class OrdersUpdateLineItemShippingDetailsResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersUpdateLineItemShippingDetailsResponse: ...

@typing.type_check_only
class OrdersUpdateMerchantOrderIdResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersUpdateMerchantOrderIdResponse: ...

@typing.type_check_only
class OrdersUpdateShipmentResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> OrdersUpdateShipmentResponse: ...

@typing.type_check_only
class PosCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PosCustomBatchResponse: ...

@typing.type_check_only
class PosInventoryResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PosInventoryResponse: ...

@typing.type_check_only
class PosListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PosListResponse: ...

@typing.type_check_only
class PosSaleResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PosSaleResponse: ...

@typing.type_check_only
class PosStoreHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PosStore: ...

@typing.type_check_only
class ProductHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Product: ...

@typing.type_check_only
class ProductDeliveryTimeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductDeliveryTime: ...

@typing.type_check_only
class ProductStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductStatus: ...

@typing.type_check_only
class ProductsCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductsCustomBatchResponse: ...

@typing.type_check_only
class ProductsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductsListResponse: ...

@typing.type_check_only
class ProductstatusesCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductstatusesCustomBatchResponse: ...

@typing.type_check_only
class ProductstatusesListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ProductstatusesListResponse: ...

@typing.type_check_only
class PromotionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Promotion: ...

@typing.type_check_only
class PubsubNotificationSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> PubsubNotificationSettings: ...

@typing.type_check_only
class RegionHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Region: ...

@typing.type_check_only
class RegionalInventoryHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RegionalInventory: ...

@typing.type_check_only
class RegionalinventoryCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RegionalinventoryCustomBatchResponse: ...

@typing.type_check_only
class RepricingRuleHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RepricingRule: ...

@typing.type_check_only
class RequestPhoneVerificationResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> RequestPhoneVerificationResponse: ...

@typing.type_check_only
class ReturnAddressHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnAddress: ...

@typing.type_check_only
class ReturnPolicyHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnPolicy: ...

@typing.type_check_only
class ReturnPolicyOnlineHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnPolicyOnline: ...

@typing.type_check_only
class ReturnShippingLabelHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnShippingLabel: ...

@typing.type_check_only
class ReturnaddressCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnaddressCustomBatchResponse: ...

@typing.type_check_only
class ReturnaddressListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnaddressListResponse: ...

@typing.type_check_only
class ReturnpolicyCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnpolicyCustomBatchResponse: ...

@typing.type_check_only
class ReturnpolicyListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ReturnpolicyListResponse: ...

@typing.type_check_only
class SearchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchResponse: ...

@typing.type_check_only
class SettlementReportHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SettlementReport: ...

@typing.type_check_only
class SettlementreportsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SettlementreportsListResponse: ...

@typing.type_check_only
class SettlementtransactionsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SettlementtransactionsListResponse: ...

@typing.type_check_only
class ShippingSettingsHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingSettings: ...

@typing.type_check_only
class ShippingsettingsCustomBatchResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingsettingsCustomBatchResponse: ...

@typing.type_check_only
class ShippingsettingsGetSupportedCarriersResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingsettingsGetSupportedCarriersResponse: ...

@typing.type_check_only
class ShippingsettingsGetSupportedHolidaysResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingsettingsGetSupportedHolidaysResponse: ...

@typing.type_check_only
class ShippingsettingsGetSupportedPickupServicesResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingsettingsGetSupportedPickupServicesResponse: ...

@typing.type_check_only
class ShippingsettingsListResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShippingsettingsListResponse: ...

@typing.type_check_only
class ShoppingAdsProgramStatusHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ShoppingAdsProgramStatus: ...

@typing.type_check_only
class VerifyPhoneNumberResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> VerifyPhoneNumberResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AnalyticsInfo(typing_extensions.TypedDict, total=False):
    googlePlayAnalytics: GooglePlayAnalytics
    itunesConnectAnalytics: ITunesConnectAnalytics

@typing.type_check_only
class AndroidInfo(typing_extensions.TypedDict, total=False):
    androidFallbackLink: str
    androidLink: str
    androidMinPackageVersionCode: str
    androidPackageName: str

@typing.type_check_only
class CreateManagedShortLinkRequest(typing_extensions.TypedDict, total=False):
    dynamicLinkInfo: DynamicLinkInfo
    longDynamicLink: str
    name: str
    sdkVersion: str
    suffix: Suffix

@typing.type_check_only
class CreateManagedShortLinkResponse(typing_extensions.TypedDict, total=False):
    managedShortLink: ManagedShortLink
    previewLink: str
    warning: _list[DynamicLinkWarning]

@typing.type_check_only
class CreateShortDynamicLinkRequest(typing_extensions.TypedDict, total=False):
    dynamicLinkInfo: DynamicLinkInfo
    longDynamicLink: str
    sdkVersion: str
    suffix: Suffix

@typing.type_check_only
class CreateShortDynamicLinkResponse(typing_extensions.TypedDict, total=False):
    previewLink: str
    shortLink: str
    warning: _list[DynamicLinkWarning]

@typing.type_check_only
class DesktopInfo(typing_extensions.TypedDict, total=False):
    desktopFallbackLink: str

@typing.type_check_only
class DeviceInfo(typing_extensions.TypedDict, total=False):
    deviceModelName: str
    languageCode: str
    languageCodeFromWebview: str
    languageCodeRaw: str
    screenResolutionHeight: str
    screenResolutionWidth: str
    timezone: str

@typing.type_check_only
class DynamicLinkEventStat(typing_extensions.TypedDict, total=False):
    count: str
    event: typing_extensions.Literal[
        "DYNAMIC_LINK_EVENT_UNSPECIFIED",
        "CLICK",
        "REDIRECT",
        "APP_INSTALL",
        "APP_FIRST_OPEN",
        "APP_RE_OPEN",
    ]
    platform: typing_extensions.Literal[
        "DYNAMIC_LINK_PLATFORM_UNSPECIFIED", "ANDROID", "IOS", "DESKTOP", "OTHER"
    ]

@typing.type_check_only
class DynamicLinkInfo(typing_extensions.TypedDict, total=False):
    analyticsInfo: AnalyticsInfo
    androidInfo: AndroidInfo
    desktopInfo: DesktopInfo
    domainUriPrefix: str
    dynamicLinkDomain: str
    iosInfo: IosInfo
    link: str
    navigationInfo: NavigationInfo
    socialMetaTagInfo: SocialMetaTagInfo

@typing.type_check_only
class DynamicLinkStats(typing_extensions.TypedDict, total=False):
    linkEventStats: _list[DynamicLinkEventStat]

@typing.type_check_only
class DynamicLinkWarning(typing_extensions.TypedDict, total=False):
    warningCode: typing_extensions.Literal[
        "CODE_UNSPECIFIED",
        "NOT_IN_PROJECT_ANDROID_PACKAGE_NAME",
        "NOT_INTEGER_ANDROID_PACKAGE_MIN_VERSION",
        "UNNECESSARY_ANDROID_PACKAGE_MIN_VERSION",
        "NOT_URI_ANDROID_LINK",
        "UNNECESSARY_ANDROID_LINK",
        "NOT_URI_ANDROID_FALLBACK_LINK",
        "BAD_URI_SCHEME_ANDROID_FALLBACK_LINK",
        "NOT_IN_PROJECT_IOS_BUNDLE_ID",
        "NOT_IN_PROJECT_IPAD_BUNDLE_ID",
        "UNNECESSARY_IOS_URL_SCHEME",
        "NOT_NUMERIC_IOS_APP_STORE_ID",
        "UNNECESSARY_IOS_APP_STORE_ID",
        "NOT_URI_IOS_FALLBACK_LINK",
        "BAD_URI_SCHEME_IOS_FALLBACK_LINK",
        "NOT_URI_IPAD_FALLBACK_LINK",
        "BAD_URI_SCHEME_IPAD_FALLBACK_LINK",
        "BAD_DEBUG_PARAM",
        "BAD_AD_PARAM",
        "DEPRECATED_PARAM",
        "UNRECOGNIZED_PARAM",
        "TOO_LONG_PARAM",
        "NOT_URI_SOCIAL_IMAGE_LINK",
        "BAD_URI_SCHEME_SOCIAL_IMAGE_LINK",
        "NOT_URI_SOCIAL_URL",
        "BAD_URI_SCHEME_SOCIAL_URL",
        "LINK_LENGTH_TOO_LONG",
        "LINK_WITH_FRAGMENTS",
        "NOT_MATCHING_IOS_BUNDLE_ID_AND_STORE_ID",
    ]
    warningDocumentLink: str
    warningMessage: str

@typing.type_check_only
class GetIosPostInstallAttributionRequest(typing_extensions.TypedDict, total=False):
    appInstallationTime: str
    bundleId: str
    device: DeviceInfo
    iosVersion: str
    retrievalMethod: typing_extensions.Literal[
        "UNKNOWN_PAYLOAD_RETRIEVAL_METHOD",
        "IMPLICIT_WEAK_MATCH",
        "EXPLICIT_WEAK_MATCH",
        "EXPLICIT_STRONG_AFTER_WEAK_MATCH",
    ]
    sdkVersion: str
    uniqueMatchLinkToCheck: str
    visualStyle: typing_extensions.Literal[
        "UNKNOWN_VISUAL_STYLE", "DEFAULT_STYLE", "CUSTOM_STYLE"
    ]

@typing.type_check_only
class GetIosPostInstallAttributionResponse(typing_extensions.TypedDict, total=False):
    appMinimumVersion: str
    attributionConfidence: typing_extensions.Literal[
        "UNKNOWN_ATTRIBUTION_CONFIDENCE", "WEAK", "DEFAULT", "UNIQUE"
    ]
    deepLink: str
    externalBrowserDestinationLink: str
    fallbackLink: str
    invitationId: str
    isStrongMatchExecutable: bool
    matchMessage: str
    requestIpVersion: typing_extensions.Literal["UNKNOWN_IP_VERSION", "IP_V4", "IP_V6"]
    requestedLink: str
    resolvedLink: str
    utmCampaign: str
    utmContent: str
    utmMedium: str
    utmSource: str
    utmTerm: str

@typing.type_check_only
class GetIosReopenAttributionRequest(typing_extensions.TypedDict, total=False):
    bundleId: str
    requestedLink: str
    sdkVersion: str

@typing.type_check_only
class GetIosReopenAttributionResponse(typing_extensions.TypedDict, total=False):
    deepLink: str
    invitationId: str
    iosMinAppVersion: str
    resolvedLink: str
    utmCampaign: str
    utmContent: str
    utmMedium: str
    utmSource: str
    utmTerm: str

@typing.type_check_only
class GooglePlayAnalytics(typing_extensions.TypedDict, total=False):
    gclid: str
    utmCampaign: str
    utmContent: str
    utmMedium: str
    utmSource: str
    utmTerm: str

@typing.type_check_only
class ITunesConnectAnalytics(typing_extensions.TypedDict, total=False):
    at: str
    ct: str
    mt: str
    pt: str

@typing.type_check_only
class IosInfo(typing_extensions.TypedDict, total=False):
    iosAppStoreId: str
    iosBundleId: str
    iosCustomScheme: str
    iosFallbackLink: str
    iosIpadBundleId: str
    iosIpadFallbackLink: str
    iosMinimumVersion: str

@typing.type_check_only
class ManagedShortLink(typing_extensions.TypedDict, total=False):
    creationTime: str
    flaggedAttribute: _list[str]
    info: DynamicLinkInfo
    link: str
    linkName: str
    visibility: typing_extensions.Literal[
        "UNSPECIFIED_VISIBILITY", "UNARCHIVED", "ARCHIVED", "NEVER_SHOWN"
    ]

@typing.type_check_only
class NavigationInfo(typing_extensions.TypedDict, total=False):
    enableForcedRedirect: bool

@typing.type_check_only
class SocialMetaTagInfo(typing_extensions.TypedDict, total=False):
    socialDescription: str
    socialImageLink: str
    socialTitle: str

@typing.type_check_only
class Suffix(typing_extensions.TypedDict, total=False):
    customSuffix: str
    option: typing_extensions.Literal[
        "OPTION_UNSPECIFIED", "UNGUESSABLE", "SHORT", "CUSTOM"
    ]



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class FirebaseRealtimeDatabaseResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class ProjectsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class LocationsResource(googleapiclient.discovery.Resource):
            @typing.type_check_only
            class InstancesResource(googleapiclient.discovery.Resource):
                def create(
                    self,
                    *,
                    parent: str,
                    body: DatabaseInstance = ...,
                    databaseId: str = ...,
                    validateOnly: bool = ...,
                    **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...
                def delete(
                    self, *, name: str, **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...
                def disable(
                    self,
                    *,
                    name: str,
                    body: DisableDatabaseInstanceRequest = ...,
                    **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...
                def get(
                    self, *, name: str, **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...
                def list(
                    self,
                    *,
                    parent: str,
                    pageSize: int = ...,
                    pageToken: str = ...,
                    showDeleted: bool = ...,
                    **kwargs: typing.Any
                ) -> ListDatabaseInstancesResponseHttpRequest: ...
                def list_next(
                    self,
                    previous_request: ListDatabaseInstancesResponseHttpRequest,
                    previous_response: ListDatabaseInstancesResponse,
                ) -> ListDatabaseInstancesResponseHttpRequest | None: ...
                def reenable(
                    self,
                    *,
                    name: str,
                    body: ReenableDatabaseInstanceRequest = ...,
                    **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...
                def undelete(
                    self,
                    *,
                    name: str,
                    body: UndeleteDatabaseInstanceRequest = ...,
                    **kwargs: typing.Any
                ) -> DatabaseInstanceHttpRequest: ...

            def instances(self) -> InstancesResource: ...

        def locations(self) -> LocationsResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def projects(self) -> ProjectsResource: ...

@typing.type_check_only
class DatabaseInstanceHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DatabaseInstance: ...

@typing.type_check_only
class ListDatabaseInstancesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ListDatabaseInstancesResponse: ...



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AchievementResetAllResponse(typing_extensions.TypedDict, total=False):
    kind: str
    results: _list[AchievementResetResponse]

@typing.type_check_only
class AchievementResetMultipleForAllRequest(typing_extensions.TypedDict, total=False):
    achievement_ids: _list[str]
    kind: str

@typing.type_check_only
class AchievementResetResponse(typing_extensions.TypedDict, total=False):
    currentState: str
    definitionId: str
    kind: str
    updateOccurred: bool

@typing.type_check_only
class EventsResetMultipleForAllRequest(typing_extensions.TypedDict, total=False):
    event_ids: _list[str]
    kind: str

@typing.type_check_only
class GamesPlayerExperienceInfoResource(typing_extensions.TypedDict, total=False):
    currentExperiencePoints: str
    currentLevel: GamesPlayerLevelResource
    lastLevelUpTimestampMillis: str
    nextLevel: GamesPlayerLevelResource

@typing.type_check_only
class GamesPlayerLevelResource(typing_extensions.TypedDict, total=False):
    level: int
    maxExperiencePoints: str
    minExperiencePoints: str

@typing.type_check_only
class HiddenPlayer(typing_extensions.TypedDict, total=False):
    hiddenTimeMillis: str
    kind: str
    player: Player

@typing.type_check_only
class HiddenPlayerList(typing_extensions.TypedDict, total=False):
    items: _list[HiddenPlayer]
    kind: str
    nextPageToken: str

@typing.type_check_only
class Player(typing_extensions.TypedDict, total=False):
    avatarImageUrl: str
    bannerUrlLandscape: str
    bannerUrlPortrait: str
    displayName: str
    experienceInfo: GamesPlayerExperienceInfoResource
    kind: str
    name: dict[str, typing.Any]
    originalPlayerId: str
    playerId: str
    profileSettings: ProfileSettings
    title: str

@typing.type_check_only
class PlayerScoreResetAllResponse(typing_extensions.TypedDict, total=False):
    kind: str
    results: _list[PlayerScoreResetResponse]

@typing.type_check_only
class PlayerScoreResetResponse(typing_extensions.TypedDict, total=False):
    definitionId: str
    kind: str
    resetScoreTimeSpans: _list[str]

@typing.type_check_only
class ProfileSettings(typing_extensions.TypedDict, total=False):
    kind: str
    profileVisible: bool

@typing.type_check_only
class ScoresResetMultipleForAllRequest(typing_extensions.TypedDict, total=False):
    kind: str
    leaderboard_ids: _list[str]



import typing

import typing_extensions

_list = list

@typing.type_check_only
class BatchDeletePhotosRequest(typing_extensions.TypedDict, total=False):
    photoIds: _list[str]

@typing.type_check_only
class BatchDeletePhotosResponse(typing_extensions.TypedDict, total=False):
    status: _list[Status]

@typing.type_check_only
class BatchGetPhotosResponse(typing_extensions.TypedDict, total=False):
    results: _list[PhotoResponse]

@typing.type_check_only
class BatchUpdatePhotosRequest(typing_extensions.TypedDict, total=False):
    updatePhotoRequests: _list[UpdatePhotoRequest]

@typing.type_check_only
class BatchUpdatePhotosResponse(typing_extensions.TypedDict, total=False):
    results: _list[PhotoResponse]

@typing.type_check_only
class Connection(typing_extensions.TypedDict, total=False):
    target: PhotoId

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GpsDataGapFailureDetails(typing_extensions.TypedDict, total=False):
    gapDuration: str
    gapStartTime: str

@typing.type_check_only
class Imu(typing_extensions.TypedDict, total=False):
    accelMpsps: _list[Measurement3d]
    gyroRps: _list[Measurement3d]
    magUt: _list[Measurement3d]

@typing.type_check_only
class ImuDataGapFailureDetails(typing_extensions.TypedDict, total=False):
    gapDuration: str
    gapStartTime: str

@typing.type_check_only
class InsufficientGpsFailureDetails(typing_extensions.TypedDict, total=False):
    gpsPointsFound: int

@typing.type_check_only
class LatLng(typing_extensions.TypedDict, total=False):
    latitude: float
    longitude: float

@typing.type_check_only
class LatLngBounds(typing_extensions.TypedDict, total=False):
    northeast: LatLng
    southwest: LatLng

@typing.type_check_only
class Level(typing_extensions.TypedDict, total=False):
    name: str
    number: float

@typing.type_check_only
class ListPhotoSequencesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    photoSequences: _list[Operation]

@typing.type_check_only
class ListPhotosResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    photos: _list[Photo]

@typing.type_check_only
class Measurement3d(typing_extensions.TypedDict, total=False):
    captureTime: str
    x: float
    y: float
    z: float

@typing.type_check_only
class NotOutdoorsFailureDetails(typing_extensions.TypedDict, total=False):
    startTime: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Photo(typing_extensions.TypedDict, total=False):
    captureTime: str
    connections: _list[Connection]
    downloadUrl: str
    mapsPublishStatus: typing_extensions.Literal[
        "UNSPECIFIED_MAPS_PUBLISH_STATUS", "PUBLISHED", "REJECTED_UNKNOWN"
    ]
    photoId: PhotoId
    places: _list[Place]
    pose: Pose
    shareLink: str
    thumbnailUrl: str
    transferStatus: typing_extensions.Literal[
        "TRANSFER_STATUS_UNKNOWN",
        "NEVER_TRANSFERRED",
        "PENDING",
        "COMPLETED",
        "REJECTED",
        "EXPIRED",
        "CANCELLED",
        "RECEIVED_VIA_TRANSFER",
    ]
    uploadReference: UploadRef
    uploadTime: str
    viewCount: str

@typing.type_check_only
class PhotoId(typing_extensions.TypedDict, total=False):
    id: str

@typing.type_check_only
class PhotoResponse(typing_extensions.TypedDict, total=False):
    photo: Photo
    status: Status

@typing.type_check_only
class PhotoSequence(typing_extensions.TypedDict, total=False):
    captureTimeOverride: str
    distanceMeters: float
    failureDetails: ProcessingFailureDetails
    failureReason: typing_extensions.Literal[
        "PROCESSING_FAILURE_REASON_UNSPECIFIED",
        "LOW_RESOLUTION",
        "DUPLICATE",
        "INSUFFICIENT_GPS",
        "NO_OVERLAP_GPS",
        "INVALID_GPS",
        "FAILED_TO_REFINE_POSITIONS",
        "TAKEDOWN",
        "CORRUPT_VIDEO",
        "INTERNAL",
        "INVALID_VIDEO_FORMAT",
        "INVALID_VIDEO_DIMENSIONS",
        "INVALID_CAPTURE_TIME",
        "GPS_DATA_GAP",
        "JUMPY_GPS",
        "INVALID_IMU",
        "INSUFFICIENT_IMU",
        "INSUFFICIENT_OVERLAP_TIME_SERIES",
        "IMU_DATA_GAP",
        "UNSUPPORTED_CAMERA",
        "NOT_OUTDOORS",
        "INSUFFICIENT_VIDEO_FRAMES",
        "INSUFFICIENT_MOVEMENT",
    ]
    filename: str
    gpsSource: typing_extensions.Literal[
        "PHOTO_SEQUENCE", "CAMERA_MOTION_METADATA_TRACK"
    ]
    id: str
    imu: Imu
    photos: _list[Photo]
    processingState: typing_extensions.Literal[
        "PROCESSING_STATE_UNSPECIFIED", "PENDING", "PROCESSING", "PROCESSED", "FAILED"
    ]
    rawGpsTimeline: _list[Pose]
    sequenceBounds: LatLngBounds
    uploadReference: UploadRef
    uploadTime: str
    viewCount: str

@typing.type_check_only
class Place(typing_extensions.TypedDict, total=False):
    languageCode: str
    name: str
    placeId: str

@typing.type_check_only
class Pose(typing_extensions.TypedDict, total=False):
    accuracyMeters: float
    altitude: float
    gpsRecordTimestampUnixEpoch: str
    heading: float
    latLngPair: LatLng
    level: Level
    pitch: float
    roll: float

@typing.type_check_only
class ProcessingFailureDetails(typing_extensions.TypedDict, total=False):
    gpsDataGapDetails: GpsDataGapFailureDetails
    imuDataGapDetails: ImuDataGapFailureDetails
    insufficientGpsDetails: InsufficientGpsFailureDetails
    notOutdoorsDetails: NotOutdoorsFailureDetails

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class UpdatePhotoRequest(typing_extensions.TypedDict, total=False):
    photo: Photo
    updateMask: str

@typing.type_check_only
class UploadRef(typing_extensions.TypedDict, total=False):
    uploadUrl: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1AccessTuple(
    typing_extensions.TypedDict, total=False
):
    fullResourceName: str
    permission: str
    principal: str

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1BindingExplanation(
    typing_extensions.TypedDict, total=False
):
    access: typing_extensions.Literal[
        "ACCESS_STATE_UNSPECIFIED",
        "GRANTED",
        "NOT_GRANTED",
        "UNKNOWN_CONDITIONAL",
        "UNKNOWN_INFO_DENIED",
    ]
    condition: GoogleTypeExpr
    memberships: dict[str, typing.Any]
    relevance: typing_extensions.Literal[
        "HEURISTIC_RELEVANCE_UNSPECIFIED", "NORMAL", "HIGH"
    ]
    role: str
    rolePermission: typing_extensions.Literal[
        "ROLE_PERMISSION_UNSPECIFIED",
        "ROLE_PERMISSION_INCLUDED",
        "ROLE_PERMISSION_NOT_INCLUDED",
        "ROLE_PERMISSION_UNKNOWN_INFO_DENIED",
    ]
    rolePermissionRelevance: typing_extensions.Literal[
        "HEURISTIC_RELEVANCE_UNSPECIFIED", "NORMAL", "HIGH"
    ]

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1BindingExplanationAnnotatedMembership(
    typing_extensions.TypedDict, total=False
):
    membership: typing_extensions.Literal[
        "MEMBERSHIP_UNSPECIFIED",
        "MEMBERSHIP_INCLUDED",
        "MEMBERSHIP_NOT_INCLUDED",
        "MEMBERSHIP_UNKNOWN_INFO_DENIED",
        "MEMBERSHIP_UNKNOWN_UNSUPPORTED",
    ]
    relevance: typing_extensions.Literal[
        "HEURISTIC_RELEVANCE_UNSPECIFIED", "NORMAL", "HIGH"
    ]

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1ExplainedPolicy(
    typing_extensions.TypedDict, total=False
):
    access: typing_extensions.Literal[
        "ACCESS_STATE_UNSPECIFIED",
        "GRANTED",
        "NOT_GRANTED",
        "UNKNOWN_CONDITIONAL",
        "UNKNOWN_INFO_DENIED",
    ]
    bindingExplanations: _list[GoogleCloudPolicytroubleshooterV1BindingExplanation]
    fullResourceName: str
    policy: GoogleIamV1Policy
    relevance: typing_extensions.Literal[
        "HEURISTIC_RELEVANCE_UNSPECIFIED", "NORMAL", "HIGH"
    ]

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyRequest(
    typing_extensions.TypedDict, total=False
):
    accessTuple: GoogleCloudPolicytroubleshooterV1AccessTuple

@typing.type_check_only
class GoogleCloudPolicytroubleshooterV1TroubleshootIamPolicyResponse(
    typing_extensions.TypedDict, total=False
):
    access: typing_extensions.Literal[
        "ACCESS_STATE_UNSPECIFIED",
        "GRANTED",
        "NOT_GRANTED",
        "UNKNOWN_CONDITIONAL",
        "UNKNOWN_INFO_DENIED",
    ]
    errors: _list[GoogleRpcStatus]
    explainedPolicies: _list[GoogleCloudPolicytroubleshooterV1ExplainedPolicy]

@typing.type_check_only
class GoogleIamV1AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[GoogleIamV1AuditLogConfig]
    service: str

@typing.type_check_only
class GoogleIamV1AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class GoogleIamV1Binding(typing_extensions.TypedDict, total=False):
    condition: GoogleTypeExpr
    members: _list[str]
    role: str

@typing.type_check_only
class GoogleIamV1Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[GoogleIamV1AuditConfig]
    bindings: _list[GoogleIamV1Binding]
    etag: str
    version: int

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class GoogleTypeExpr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str
